/// <reference types="node" />
import * as net from 'net';
import * as tls from 'tls';
import { EventEmitter } from 'events';
import { Observable } from 'rxjs';
export declare function _SET_IDLE_TIMEOUT_DEFAULT(t: number): void;
export declare type ResponderFunction = (response: any) => void;
export declare type ObservableResponderFunction = (resp: Observable<any> | undefined) => void;
interface RPCClientOptions {
    handler: RPCClientHandler;
    host: string;
    port: number;
    token: string;
    fingerprint?: string;
    rejectUnauthorized?: boolean;
}
export declare class RPCClient extends EventEmitter {
    private socket;
    private closed;
    private rl;
    private msgId;
    private observableId;
    private handler;
    private idleTimeout;
    private peerIdleTimeout;
    private lastTransmit;
    private lastReceive;
    private observers;
    private subscriptions;
    private outstandingQuestionMap;
    private initialized;
    private fingerprint;
    private idleTimer?;
    private peerIdleTimer?;
    constructor(p1: RPCClientOptions | tls.TLSSocket | net.Socket);
    cleanup(): void;
    setHandler(handler: RPCClientHandler): void;
    on(event: 'initialized' | 'error', listener: (token: string) => void): this;
    sendMessage(message: any): void;
    askQuestion(question: any, timeout?: number): Promise<any>;
    requestObservable(params: any): Observable<any>;
    outstandingQuestions(): number;
    close(): void;
    _accept(): void;
    _deny(): void;
    _observers(): number;
    _subscriptions(): number;
    private send;
    private sendInit;
    private respond;
    private respondError;
    private receive;
    private setPeerIdleTimeout;
    checkPeerIdle(): void;
    private setIdleTimeout;
    private avoidIdle;
}
export declare abstract class RPCClientHandler extends EventEmitter {
    constructor();
    client: RPCClient | undefined;
    private closedDeferred;
    closed: Promise<void>;
    initialize(client: RPCClient): void;
    onConnect(): void;
    onClose(_had_error: boolean): Promise<void>;
    abstract onMessage(_message: any): void;
    abstract onQuestion(_question: any): Promise<any>;
    abstract onRequestObservable(_params: any): Observable<any> | undefined;
    onError(err: Error): void;
}
export {};
