/// <reference types="node" />
import * as net from 'net';
import * as tls from 'tls';
import { EventEmitter } from 'events';
import { RPCClient, RPCClientHandler } from './rpc-client';
interface RPCServerOptionsSecure {
    tls: true;
    key: tls.TlsOptions['key'];
    cert: tls.TlsOptions['cert'];
}
interface RPCServerOptionsInsecure {
    tls: false;
}
declare type RPCServerOptions = RPCServerOptionsInsecure | RPCServerOptionsSecure;
export declare class RPCServer extends EventEmitter {
    private server;
    private cert?;
    private unusedTokens;
    private defaultHandler;
    constructor(options: RPCServerOptions);
    on(event: 'listening' | 'close', listener: () => void): this;
    on(event: 'error', listener: (error: Error) => void): this;
    on(event: 'connection', listener: (client: RPCClient, token: string, cb: (accept: boolean) => void) => void): this;
    on(event: 'invalid_token', listener: (ip: string, token: string) => void): this;
    fingerprint(): Promise<string>;
    address(): net.AddressInfo | null;
    listen(port: number, ip: string): void;
    close(): void;
    registerClientHandler(clientHandler: RPCClientHandler, timeoutMs?: number, token?: string): string;
    registerDefaultHandler(defaultHandler: (token: string) => RPCClientHandler | undefined): void;
    private newClient;
}
export {};
